@@ -643,8 +643,7 @@ bool ManagerPrivate::doQuery(const QUrl &url, QWidget *parent,
             if ( !attr.isNull() ) {
                 // see DUMMY_STRINGS
                 QString msg = i18n(attr.value().toLatin1().constData());
-                QString caption = i18n("Message from world-wide highscores "
-                                       "server");
+                QString caption = i18nc("@title:window", "Message from World-Wide High Scores Server");
                 KMessageBox::error(parent, msg, caption);
                 return false;
             }
@@ -787,7 +786,7 @@ int ManagerPrivate::submitScore(const Score &ascore,
     score.setData(QStringLiteral( "date" ), QDateTime::currentDateTime());
 
     // ask new name if anonymous and winner
-    const QLatin1String dontAskAgainName = QLatin1String( "highscore_ask_name_dialog" );
+    const QString dontAskAgainName = QStringLiteral("highscore_ask_name_dialog");
     QString newName;
     KMessageBox::ButtonCode dummy;
     if ( score.type()==Won && askIfAnonymous && _playerInfos->isAnonymous()
